@@ -1,14 +1,14 @@
-package Regexp::Pattern::YouTube;
+package Regexp::Pattern::Twitter;
 
 our $DATE = '2017-01-22'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 our %RE = (
     username => { pat => qr/[0-9A-Za-z_]{1,15}/ },
 );
 
 1;
-# ABSTRACT: Regexp patterns related to YouTube
+# ABSTRACT: Regexp patterns related to Twitter
 
 __END__
 
@@ -18,11 +18,16 @@ __END__
 
 =head1 NAME
 
-Regexp::Pattern::YouTube - Regexp patterns related to YouTube
+Regexp::Pattern::Twitter - Regexp patterns related to Twitter
 
 =head1 VERSION
 
-This document describes version 0.001 of Regexp::Pattern::YouTube (from Perl distribution Regexp-Pattern-Twitter), released on 2017-01-22.
+This document describes version 0.002 of Regexp::Pattern::Twitter (from Perl distribution Regexp-Pattern-Twitter), released on 2017-01-22.
+
+=head1 SYNOPSIS
+
+ use Regexp::Pattern; # exports re()
+ my $re = re("Twitter::username");
 
 =head1 DESCRIPTION
 
@@ -32,6 +37,8 @@ L<Regexp::Pattern> is a convention for organizing reusable regex patterns.
 
 =over
 
+=item * username
+
 =back
 
 =head1 HOMEPAGE
